pub struct TextureAtlas { /* private fields */ }Expand description
The TextureAtlas maintains the per-frame descriptor sets used for binding textures.
New textures can be added to the atlas at any time and will be available for use in the next frame.
Shader Requirements
To use the texture atlas, the fragment shader must include a descriptor set with a sampler binding and a texture binding. This looks something like this in glsl:
layout(set = 0, binding = 0) uniform sampler u_Sampler;
layout(set = 0, binding = 1) uniform texture2D u_Textures[];Implementations
Sourceimpl TextureAtlas
impl TextureAtlas
pub fn new(ctx: &VulkanContext) -> Result<Self>
pub fn descriptor_set_layout(&self) -> &DescriptorSetLayout
Sourcepub fn descriptor_set(&self) -> DescriptorSet
pub fn descriptor_set(&self) -> DescriptorSet
Returns the atlas’s descriptor set.
Used by the application to bind the atlas descriptor.
Sourcepub fn add_texture(&mut self, ctx: &VulkanContext, texture: Arc<Texture>) -> i32
pub fn add_texture(&mut self, ctx: &VulkanContext, texture: Arc<Texture>) -> i32
Adds a texture to the atlas and returns the index which can be used in vertices to reference the texture again.
Sourcepub fn get_texture(&self, texture_id: i32) -> &Arc<Texture>
pub fn get_texture(&self, texture_id: i32) -> &Arc<Texture>
Fetchs a texture by the id returned by Self::add_texture.