TrianglesMesh

Struct TrianglesMesh 

pub struct TrianglesMesh { /* private fields */ }
This mesh supports drawing arbitrary triangles and quads in three dimensions.

Implementations

Source

impl TrianglesMesh

pub fn new(initial_capacity: usize, material: Arc<Material>) -> Self

Creates a new empty Mesh with pre-allocated internal memory for vertex data.

pub fn set_scissor(&mut self, rect: Rect2D)

pub fn set_transform(&mut self, projection: Matrix4<f32>)

Set the matrix transformation matrix.

pub fn clear(&mut self)

Clears all geometry from the Mesh while retaining any allocated memory.

pub fn indexed_triangles<V, I>(&mut self, vertices: V, indices: I)
where V: Iterator<Item = Vertex>, I: Iterator<Item = u32>,

pub fn triangle( &mut self, color: [f32; 4], texture_index: i32, p1: Vector3<f32>, p2: Vector3<f32>, p3: Vector3<f32>, )

Adds a triangle to the mesh.

Note: triangles must be in clockwise winding order, else they will be culled.

pub fn quad( &mut self, color: [f32; 4], texture_index: i32, top_left: Vector3<f32>, top_right: Vector3<f32>, bot_right: Vector3<f32>, bot_left: Vector3<f32>, )

Adds a quad to the mesh.

Note: corners should be specified in a clockwise winding order, else the triangles that make up the resulting quad may be culled.